==> 1.0.119+1.tar.gz: lib/components/UikTwoComponentRow.dart <==
// ignore_for_file: prefer_final_fields, no_logic_in_create_state

import "package:flutter/material.dart";
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

import '../props/UikTwoComponentRowProps.dart';
import 'UikWidget.dart';

// ignore: must_be_immutable
class UikTwoComponentRow extends UikWidget {
  // ignore: unused_field
  WidgetType _widgetType;
  UikTwoComponentRowProps _uikTwoComponentRowProps;
  UikTwoComponentRow(this._widgetType, this._uikTwoComponentRowProps)
      : super(_widgetType, _uikTwoComponentRowProps);

  @override
  _UikTwoComponentRowState createState() =>
      _UikTwoComponentRowState(_uikTwoComponentRowProps);
}

class _UikTwoComponentRowState extends State<UikTwoComponentRow> {
  UikTwoComponentRowProps _uikTwoComponentRowProps;
  _UikTwoComponentRowState(this._uikTwoComponentRowProps);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () async {
        await executeUikWidgetAction(_uikTwoComponentRowProps.action);
      },
      child: Container(
        padding: _uikTwoComponentRowProps.enablePadding
            ? const EdgeInsets.all(10.0)
            : null,
        margin: EdgeInsets.only(
          top: _uikTwoComponentRowProps.marginTop,
          bottom: _uikTwoComponentRowProps.marginBottom,
          left: _uikTwoComponentRowProps.marginLeft,
          right: _uikTwoComponentRowProps.marginRight,
        ),
        decoration: BoxDecoration(
          color: (_uikTwoComponentRowProps.opacity != null)
              ? _uikTwoComponentRowProps.bgcolor
                  .withOpacity(_uikTwoComponentRowProps.opacity!)
              : _uikTwoComponentRowProps.bgcolor,
          borderRadius:
              BorderRadius.circular(_uikTwoComponentRowProps.borderRadius),
        ),
        child: Row(
          mainAxisAlignment: _uikTwoComponentRowProps.mainAxisAlignment,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            _uikTwoComponentRowProps.firstComponent!,
            _uikTwoComponentRowProps.secondComponent!,
          ],
        ),
      ),
    );
  }
}

==> 1.0.120+1.tar.gz: lib/components/UikTwoComponentRow.dart <==
// ignore_for_file: prefer_final_fields, no_logic_in_create_state

import "package:flutter/material.dart";
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

import '../props/UikTwoComponentRowProps.dart';
import 'UikWidget.dart';

// ignore: must_be_immutable
class UikTwoComponentRow extends UikWidget {
  // ignore: unused_field
  WidgetType _widgetType;
  UikTwoComponentRowProps _uikTwoComponentRowProps;
  UikTwoComponentRow(this._widgetType, this._uikTwoComponentRowProps)
      : super(_widgetType, _uikTwoComponentRowProps);

  @override
  _UikTwoComponentRowState createState() =>
      _UikTwoComponentRowState(_uikTwoComponentRowProps);
}

class _UikTwoComponentRowState extends State<UikTwoComponentRow> {
  UikTwoComponentRowProps _uikTwoComponentRowProps;
  _UikTwoComponentRowState(this._uikTwoComponentRowProps);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () async {
        await executeUikWidgetAction(_uikTwoComponentRowProps.action);
      },
      child: Container(
        padding: _uikTwoComponentRowProps.enablePadding
            ? const EdgeInsets.all(0)
            : null,
        margin: EdgeInsets.only(
          top: _uikTwoComponentRowProps.marginTop,
          bottom: _uikTwoComponentRowProps.marginBottom,
          left: _uikTwoComponentRowProps.marginLeft,
          right: _uikTwoComponentRowProps.marginRight,
        ),
        decoration: BoxDecoration(
          color: (_uikTwoComponentRowProps.opacity != null)
              ? _uikTwoComponentRowProps.bgcolor
                  .withOpacity(_uikTwoComponentRowProps.opacity!)
              : _uikTwoComponentRowProps.bgcolor,
          borderRadius: BorderRadius.only(
            topLeft: Radius.circular(_uikTwoComponentRowProps.borderRadius),
            topRight: Radius.circular(_uikTwoComponentRowProps.borderRadius),
            bottomRight: Radius.circular(_uikTwoComponentRowProps.borderRadius),
            bottomLeft: Radius.circular(_uikTwoComponentRowProps.borderRadius),
          ),
          // BorderRadius.circular(_uikTwoComponentRowProps.borderRadius),
        ),
        child: Row(
          mainAxisAlignment: _uikTwoComponentRowProps.mainAxisAlignment,
          children: [
            _uikTwoComponentRowProps.firstComponent!,
            _uikTwoComponentRowProps.secondComponent!,
          ],
        ),
      ),
    );
  }
}
